# tacp
CP web services provides API access to the ThinkAgile CP on-premises cloud platform. It provides access to virtual datacenter and infrastructure resources and is used to create resizable resources, manage workloads and retrieve information about the underlying infrastructure. CPWS will continue to grow as new capabilities are added to the platform.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: Beta
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
For more information, please visit [https://cp.lenovo.com](https://cp.lenovo.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://hpcgitlab.labs.lenovo.com/CLX/tacp-python-api-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import tacp 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import tacp
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import tacp
from tacp.rest import ApiException
from pprint import pprint

# Configure API key authorization: apiKey
configuration = tacp.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = tacp.ActionsApi(tacp.ApiClient(configuration))
uuid = 'uuid_example' # str | uuid

try:
    # View an action
    api_response = api_instance.get_action_using_get(uuid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ActionsApi->get_action_using_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://manage.cp.lenovo.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActionsApi* | [**get_action_using_get**](docs/ActionsApi.md#get_action_using_get) | **GET** /api/latest/actions/{uuid} | View an action
*ApplicationGroupsApi* | [**assign_applications_using_put**](docs/ApplicationGroupsApi.md#assign_applications_using_put) | **PUT** /api/latest/application-groups/{uuid}/assign-applications | Assign applications to an application group
*ApplicationGroupsApi* | [**create_application_group_using_post**](docs/ApplicationGroupsApi.md#create_application_group_using_post) | **POST** /api/latest/application-groups | Create an application group
*ApplicationGroupsApi* | [**delete_application_group_by_uuid_using_delete**](docs/ApplicationGroupsApi.md#delete_application_group_by_uuid_using_delete) | **DELETE** /api/latest/application-groups/{uuid} | Delete an application group
*ApplicationGroupsApi* | [**get_application_group_information_using_get**](docs/ApplicationGroupsApi.md#get_application_group_information_using_get) | **GET** /api/latest/application-groups/{uuid} | View the properties of an application group
*ApplicationGroupsApi* | [**get_application_group_list_using_get**](docs/ApplicationGroupsApi.md#get_application_group_list_using_get) | **GET** /api/latest/application-groups | View application groups for an organization
*ApplicationGroupsApi* | [**remove_applications_using_put**](docs/ApplicationGroupsApi.md#remove_applications_using_put) | **PUT** /api/latest/application-groups/{uuid}/remove-applications | Remove applications from an application group
*ApplicationGroupsApi* | [**rename_application_group_using_put**](docs/ApplicationGroupsApi.md#rename_application_group_using_put) | **PUT** /api/latest/application-groups/{uuid}/name | Rename an application group
*ApplicationsApi* | [**clone_and_attach_disk_to_application_using_put**](docs/ApplicationsApi.md#clone_and_attach_disk_to_application_using_put) | **PUT** /api/latest/applications/{uuid}/clone-and-attach-disk | Clone and attach a disk to an application
*ApplicationsApi* | [**create_application_from_snapshot_using_post**](docs/ApplicationsApi.md#create_application_from_snapshot_using_post) | **POST** /api/latest/applications/create-from-snapshot | Create an application from a snapshot
*ApplicationsApi* | [**create_application_from_template_using_post**](docs/ApplicationsApi.md#create_application_from_template_using_post) | **POST** /api/latest/applications | Create an application from a template
*ApplicationsApi* | [**create_snapshot_for_application_using_post**](docs/ApplicationsApi.md#create_snapshot_for_application_using_post) | **POST** /api/latest/applications/{uuid}/snapshots | Create a snapshot for an application
*ApplicationsApi* | [**delete_application_using_delete**](docs/ApplicationsApi.md#delete_application_using_delete) | **DELETE** /api/latest/applications/{uuid} | Delete an application
*ApplicationsApi* | [**delete_snapshot_for_application_using_delete**](docs/ApplicationsApi.md#delete_snapshot_for_application_using_delete) | **DELETE** /api/latest/applications/{uuid}/snapshots/{snapshot_uuid} | Deleting snapshot for an application
*ApplicationsApi* | [**edit_application_using_put**](docs/ApplicationsApi.md#edit_application_using_put) | **PUT** /api/latest/applications/{uuid} | Edit an application (deprecated)
*ApplicationsApi* | [**force_restart_application_using_put**](docs/ApplicationsApi.md#force_restart_application_using_put) | **PUT** /api/latest/applications/{uuid}/force-restart | Force restart an application
*ApplicationsApi* | [**get_application_disk_stats_using_get**](docs/ApplicationsApi.md#get_application_disk_stats_using_get) | **GET** /api/latest/applications/{uuid}/disks/{disk_uuid} | View disk statistics for an application
*ApplicationsApi* | [**get_application_stats_using_get**](docs/ApplicationsApi.md#get_application_stats_using_get) | **GET** /api/latest/applications/{uuid}/stats | View statistics for an application
*ApplicationsApi* | [**get_application_using_get**](docs/ApplicationsApi.md#get_application_using_get) | **GET** /api/latest/applications/{uuid} | View an application
*ApplicationsApi* | [**get_applications_using_get**](docs/ApplicationsApi.md#get_applications_using_get) | **GET** /api/latest/applications | View applications for an organization
*ApplicationsApi* | [**get_firewall_overrides_for_application_using_get**](docs/ApplicationsApi.md#get_firewall_overrides_for_application_using_get) | **GET** /api/latest/applications/{uuid}/firewall-overrides | View a list of firewall overrides for an application
*ApplicationsApi* | [**get_snapshot_using_get**](docs/ApplicationsApi.md#get_snapshot_using_get) | **GET** /api/latest/applications/{uuid}/snapshots/{snapshot_uuid} | View a snapshot for an application
*ApplicationsApi* | [**get_snapshots_for_application_using_get**](docs/ApplicationsApi.md#get_snapshots_for_application_using_get) | **GET** /api/latest/applications/{uuid}/snapshots | View snapshots for an application
*ApplicationsApi* | [**pause_application_using_put**](docs/ApplicationsApi.md#pause_application_using_put) | **PUT** /api/latest/applications/{uuid}/suspend | Pause an application
*ApplicationsApi* | [**rename_snapshot_using_put**](docs/ApplicationsApi.md#rename_snapshot_using_put) | **PUT** /api/latest/applications/{uuid}/snapshots/{snapshot_uuid}/name | Rename a snapshot
*ApplicationsApi* | [**restart_application_using_put**](docs/ApplicationsApi.md#restart_application_using_put) | **PUT** /api/latest/applications/{uuid}/restart | Restart an application
*ApplicationsApi* | [**resume_application_using_put**](docs/ApplicationsApi.md#resume_application_using_put) | **PUT** /api/latest/applications/{uuid}/resume | Resume an application
*ApplicationsApi* | [**shutdown_application_using_put**](docs/ApplicationsApi.md#shutdown_application_using_put) | **PUT** /api/latest/applications/{uuid}/shutdown | Shutdown an application
*ApplicationsApi* | [**start_application_using_put**](docs/ApplicationsApi.md#start_application_using_put) | **PUT** /api/latest/applications/{uuid}/start | Start an application
*ApplicationsApi* | [**stop_application_using_put**](docs/ApplicationsApi.md#stop_application_using_put) | **PUT** /api/latest/applications/{uuid}/stop | Stop an application
*CategoriesApi* | [**get_categories_using_get**](docs/CategoriesApi.md#get_categories_using_get) | **GET** /api/latest/categories | View categories for an organization
*CategoriesApi* | [**get_category_using_get**](docs/CategoriesApi.md#get_category_using_get) | **GET** /api/latest/categories/{uuid} | View properties of a category
*ComputeNodesApi* | [**get_compute_node_information_using_get**](docs/ComputeNodesApi.md#get_compute_node_information_using_get) | **GET** /api/latest/compute-nodes/{uuid} | View the properties of a compute node
*ComputeNodesApi* | [**get_compute_node_stats_using_get**](docs/ComputeNodesApi.md#get_compute_node_stats_using_get) | **GET** /api/latest/compute-nodes/{uuid}/stats | View the statistics of a compute node
*ComputeNodesApi* | [**get_compute_nodes_for_organization_using_get**](docs/ComputeNodesApi.md#get_compute_nodes_for_organization_using_get) | **GET** /api/latest/compute-nodes | View compute nodes for an organization
*ComputeNodesApi* | [**update_tags_to_compute_node_using_put**](docs/ComputeNodesApi.md#update_tags_to_compute_node_using_put) | **PUT** /api/latest/compute-nodes/{uuid}/tags | Update tags for Compute Node
*DatacentersApi* | [**create_datacenter_using_post**](docs/DatacentersApi.md#create_datacenter_using_post) | **POST** /api/latest/datacenters | Create datacenter
*DatacentersApi* | [**get_datacenter_firewall_overrides_using_get**](docs/DatacentersApi.md#get_datacenter_firewall_overrides_using_get) | **GET** /api/latest/datacenters/{uuid}/firewall-overrides | View firewall overrides for a datacenter
*DatacentersApi* | [**get_datacenter_templates_using_get**](docs/DatacentersApi.md#get_datacenter_templates_using_get) | **GET** /api/latest/datacenters/{uuid}/templates | View templates for a datacenter
*DatacentersApi* | [**get_datacenter_using_get**](docs/DatacentersApi.md#get_datacenter_using_get) | **GET** /api/latest/datacenters/{uuid} | View the properties of a datacenter
*DatacentersApi* | [**get_datacenters_using_get**](docs/DatacentersApi.md#get_datacenters_using_get) | **GET** /api/latest/datacenters | View datacenters for an organization
*DatacentersApi* | [**unassign_networks_from_datacenter_using_put**](docs/DatacentersApi.md#unassign_networks_from_datacenter_using_put) | **PUT** /api/latest/datacenters/{uuid}/unassign-networks | Unassign networks from Datacenter
*DatacentersApi* | [**update_networks_to_datacenter_using_put**](docs/DatacentersApi.md#update_networks_to_datacenter_using_put) | **PUT** /api/latest/datacenters/{uuid}/assign-networks | Assign networks to Datacenter
*DatacentersApi* | [**update_user_role_for_datacenter_using_put**](docs/DatacentersApi.md#update_user_role_for_datacenter_using_put) | **PUT** /api/latest/datacenters/{uuid}/users/{user_uuid} | Add/remove user to/from a datacenter
*DefaultsApi* | [**get_operating_system_versions_using_get**](docs/DefaultsApi.md#get_operating_system_versions_using_get) | **GET** /api/latest/operating-system-versions | View the operation system versions
*EditApplicationsApi* | [**create_application_disk_using_post**](docs/EditApplicationsApi.md#create_application_disk_using_post) | **POST** /api/latest/applications/{uuid}/disks | Add a disk to an application
*EditApplicationsApi* | [**create_application_vnic_using_post**](docs/EditApplicationsApi.md#create_application_vnic_using_post) | **POST** /api/latest/applications/{uuid}/vnics | Add a vNIC to an application
*EditApplicationsApi* | [**delete_application_disk_using_delete**](docs/EditApplicationsApi.md#delete_application_disk_using_delete) | **DELETE** /api/latest/applications/{uuid}/disks/{disk_uuid} | Delete a disk from an application
*EditApplicationsApi* | [**delete_application_vnic_using_delete**](docs/EditApplicationsApi.md#delete_application_vnic_using_delete) | **DELETE** /api/latest/applications/{uuid}/vnics/{vnic_uuid} | Delete a vNIC from an application
*EditApplicationsApi* | [**edit_application_boot_order_using_put**](docs/EditApplicationsApi.md#edit_application_boot_order_using_put) | **PUT** /api/latest/applications/{uuid}/boot-order | Update the boot order for an application
*EditApplicationsApi* | [**edit_application_compute_category_using_put**](docs/EditApplicationsApi.md#edit_application_compute_category_using_put) | **PUT** /api/latest/applications/{uuid}/compute-category | Update the category for an application
*EditApplicationsApi* | [**edit_application_compute_tags_using_put**](docs/EditApplicationsApi.md#edit_application_compute_tags_using_put) | **PUT** /api/latest/applications/{uuid}/compute-tags | Update compute tags for an application
*EditApplicationsApi* | [**edit_application_datacenter_using_put**](docs/EditApplicationsApi.md#edit_application_datacenter_using_put) | **PUT** /api/latest/applications/{uuid}/datacenter | Update datacenter for an application
*EditApplicationsApi* | [**edit_application_description_using_put**](docs/EditApplicationsApi.md#edit_application_description_using_put) | **PUT** /api/latest/applications/{uuid}/description | Update description for an application
*EditApplicationsApi* | [**edit_application_disk_bandwidth_limit_using_put**](docs/EditApplicationsApi.md#edit_application_disk_bandwidth_limit_using_put) | **PUT** /api/latest/applications/{uuid}/disks/{disk_uuid}/bandwidth-limit | Update disk bandwidth limit for an application
*EditApplicationsApi* | [**edit_application_disk_iops_limit_using_put**](docs/EditApplicationsApi.md#edit_application_disk_iops_limit_using_put) | **PUT** /api/latest/applications/{uuid}/disks/{disk_uuid}/iops-limit | Update disk iops limit for an application
*EditApplicationsApi* | [**edit_application_disk_name_using_put**](docs/EditApplicationsApi.md#edit_application_disk_name_using_put) | **PUT** /api/latest/applications/{uuid}/disks/{disk_uuid}/name | Update disk name for an application
*EditApplicationsApi* | [**edit_application_disk_size_using_put**](docs/EditApplicationsApi.md#edit_application_disk_size_using_put) | **PUT** /api/latest/applications/{uuid}/disks/{disk_uuid}/size | Resize an application disk
*EditApplicationsApi* | [**edit_application_memory_using_put**](docs/EditApplicationsApi.md#edit_application_memory_using_put) | **PUT** /api/latest/applications/{uuid}/memory | Update memory for an application
*EditApplicationsApi* | [**edit_application_migration_zone_using_put**](docs/EditApplicationsApi.md#edit_application_migration_zone_using_put) | **PUT** /api/latest/applications/{uuid}/migration-zone | Update migration zone for an application
*EditApplicationsApi* | [**edit_application_name_using_put**](docs/EditApplicationsApi.md#edit_application_name_using_put) | **PUT** /api/latest/applications/{uuid}/name | Update name for an application
*EditApplicationsApi* | [**edit_application_vcpus_using_put**](docs/EditApplicationsApi.md#edit_application_vcpus_using_put) | **PUT** /api/latest/applications/{uuid}/vcpus | Update virtual CPUs for an application
*EditApplicationsApi* | [**edit_application_vnic_firewall_using_put**](docs/EditApplicationsApi.md#edit_application_vnic_firewall_using_put) | **PUT** /api/latest/applications/{uuid}/vnics/{vnic_uuid}/firewall | Update vNIC firewall override for an application
*EditApplicationsApi* | [**edit_application_vnic_mac_address_using_put**](docs/EditApplicationsApi.md#edit_application_vnic_mac_address_using_put) | **PUT** /api/latest/applications/{uuid}/vnics/{vnic_uuid}/mac-address | Update vNIC MAC address for an application
*EditApplicationsApi* | [**edit_application_vnic_name_using_put**](docs/EditApplicationsApi.md#edit_application_vnic_name_using_put) | **PUT** /api/latest/applications/{uuid}/vnics/{vnic_uuid}/name | Update vNIC name for an application
*EditApplicationsApi* | [**edit_application_vnic_type_using_put**](docs/EditApplicationsApi.md#edit_application_vnic_type_using_put) | **PUT** /api/latest/applications/{uuid}/vnics/{vnic_uuid}/type | Update vNIC networking mode for an application
*EditApplicationsApi* | [**toggle_application_automatic_recovery_using_put**](docs/EditApplicationsApi.md#toggle_application_automatic_recovery_using_put) | **PUT** /api/latest/applications/{uuid}/automatic-recovery | Toggle automatic recovery for an application
*EditApplicationsApi* | [**toggle_application_hardware_assisted_virtualization_using_put**](docs/EditApplicationsApi.md#toggle_application_hardware_assisted_virtualization_using_put) | **PUT** /api/latest/applications/{uuid}/hardware-assisted-virtualization | Toggle nested virtualization for an application
*EditApplicationsApi* | [**toggle_application_vm_mode_using_put**](docs/EditApplicationsApi.md#toggle_application_vm_mode_using_put) | **PUT** /api/latest/applications/{uuid}/vm-mode | Update virtual machine mode for an application
*EventsApi* | [**get_notifications_using_get**](docs/EventsApi.md#get_notifications_using_get) | **GET** /api/latest/events | View notifications for an organization
*FirewallProfilesApi* | [**get_firewall_profiles_using_get**](docs/FirewallProfilesApi.md#get_firewall_profiles_using_get) | **GET** /api/latest/firewall-profiles | View firewall profiles for an organization
*FlashPoolsApi* | [**get_flash_pool_stats_using_get**](docs/FlashPoolsApi.md#get_flash_pool_stats_using_get) | **GET** /api/latest/flash-pools/{uuid}/stats | View the statistics for a flash pool
*FlashPoolsApi* | [**get_flash_pool_using_get**](docs/FlashPoolsApi.md#get_flash_pool_using_get) | **GET** /api/latest/flash-pools/{uuid} | View the properties of a flash pool
*FlashPoolsApi* | [**get_flash_pools_using_get**](docs/FlashPoolsApi.md#get_flash_pools_using_get) | **GET** /api/latest/flash-pools | View flash pools for an organization
*LocationsApi* | [**get_location_information_using_get**](docs/LocationsApi.md#get_location_information_using_get) | **GET** /api/latest/locations/{uuid} | View the properties of a location
*LocationsApi* | [**get_locations_for_organization_using_get**](docs/LocationsApi.md#get_locations_for_organization_using_get) | **GET** /api/latest/locations | View locations for an organization
*MarketplaceTemplatesApi* | [**download_marketplace_template_using_put**](docs/MarketplaceTemplatesApi.md#download_marketplace_template_using_put) | **PUT** /api/latest/marketplace-templates/{uuid} | Download marketplace template
*MarketplaceTemplatesApi* | [**get_marketplace_templates_using_get**](docs/MarketplaceTemplatesApi.md#get_marketplace_templates_using_get) | **GET** /api/latest/marketplace-templates | View marketplace templates for an organization
*MigrationZonesApi* | [**get_migration_zone_stats_using_get**](docs/MigrationZonesApi.md#get_migration_zone_stats_using_get) | **GET** /api/latest/migration-zones/{uuid}/stats | View statistics for a migration zone
*MigrationZonesApi* | [**get_migration_zone_using_get**](docs/MigrationZonesApi.md#get_migration_zone_using_get) | **GET** /api/latest/migration-zones/{uuid} | View the properties of a migration zone
*MigrationZonesApi* | [**get_migration_zones_using_get**](docs/MigrationZonesApi.md#get_migration_zones_using_get) | **GET** /api/latest/migration-zones | View migration zones for an organization
*StorageBlocksApi* | [**get_storage_block_information_using_get**](docs/StorageBlocksApi.md#get_storage_block_information_using_get) | **GET** /api/latest/storage-blocks/{uuid} | View the properties of a storage block
*StorageBlocksApi* | [**get_storage_blocks_using_get**](docs/StorageBlocksApi.md#get_storage_blocks_using_get) | **GET** /api/latest/storage-blocks | View storage blocks for an organization
*StorageControllersApi* | [**get_storage_controller_information_using_get**](docs/StorageControllersApi.md#get_storage_controller_information_using_get) | **GET** /api/latest/storage-controllers/{uuid} | View the properties of a storage controller
*StorageControllersApi* | [**get_storage_controllers_using_get**](docs/StorageControllersApi.md#get_storage_controllers_using_get) | **GET** /api/latest/storage-controllers | View storage controllers for an organization
*TagsApi* | [**get_tag_using_get**](docs/TagsApi.md#get_tag_using_get) | **GET** /api/latest/tags/{uuid} | View the properties of a tag
*TagsApi* | [**get_tags_using_get**](docs/TagsApi.md#get_tags_using_get) | **GET** /api/latest/tags | View tags for an organization
*TemplatesApi* | [**create_template_from_application_using_post**](docs/TemplatesApi.md#create_template_from_application_using_post) | **POST** /api/latest/templates | Create a template from an application
*TemplatesApi* | [**delete_application_template_using_delete**](docs/TemplatesApi.md#delete_application_template_using_delete) | **DELETE** /api/latest/templates/{uuid} | Delete an application template
*TemplatesApi* | [**get_template_using_get**](docs/TemplatesApi.md#get_template_using_get) | **GET** /api/latest/templates/{uuid} | View the properties of a template
*TemplatesApi* | [**get_templates_using_get**](docs/TemplatesApi.md#get_templates_using_get) | **GET** /api/latest/templates | View the templates for an organization
*TemplatesApi* | [**import_vm_to_application_template_using_post**](docs/TemplatesApi.md#import_vm_to_application_template_using_post) | **POST** /api/latest/templates/import-vm | Import a VM to an application template
*UsersApi* | [**get_users_using_get**](docs/UsersApi.md#get_users_using_get) | **GET** /api/latest/users | View users for organization
*VersionApi* | [**get_version_using_get**](docs/VersionApi.md#get_version_using_get) | **GET** /api/latest/version | View the ThinkAgile CP version
*VlansApi* | [**create_vlan_using_post**](docs/VlansApi.md#create_vlan_using_post) | **POST** /api/latest/vlans | Create a new VLAN
*VlansApi* | [**delete_vlan_using_delete**](docs/VlansApi.md#delete_vlan_using_delete) | **DELETE** /api/latest/vlans/{uuid} | Delete a VLAN
*VlansApi* | [**get_vlan_using_get**](docs/VlansApi.md#get_vlan_using_get) | **GET** /api/latest/vlans/{uuid} | View the properties for a VLAN
*VlansApi* | [**get_vlans_using_get**](docs/VlansApi.md#get_vlans_using_get) | **GET** /api/latest/vlans | View VLANs for an organization
*VlansApi* | [**rename_vlan_using_put**](docs/VlansApi.md#rename_vlan_using_put) | **PUT** /api/latest/vlans/{uuid}/name | Rename a VLAN
*VnetsApi* | [**create_vnet_using_post**](docs/VnetsApi.md#create_vnet_using_post) | **POST** /api/latest/vnets | Create a VNET
*VnetsApi* | [**delete_vnet_using_delete**](docs/VnetsApi.md#delete_vnet_using_delete) | **DELETE** /api/latest/vnets/{uuid} | Delete a VNET
*VnetsApi* | [**deploy_nfv_instance_to_vnet_using_put**](docs/VnetsApi.md#deploy_nfv_instance_to_vnet_using_put) | **PUT** /api/latest/vnets/{uuid}/deploy-nfv-instance | Deploy a NFV instance to a VNET
*VnetsApi* | [**edit_vnet_firewall_profile_using_put**](docs/VnetsApi.md#edit_vnet_firewall_profile_using_put) | **PUT** /api/latest/vnets/{uuid}/firewall-profile | Update firewall profile for a VNET
*VnetsApi* | [**edit_vnet_properties_using_put**](docs/VnetsApi.md#edit_vnet_properties_using_put) | **PUT** /api/latest/vnets/{uuid}/properties-and-dhcp | Update basic properties for a VNET
*VnetsApi* | [**edit_vnet_routing_service_using_put**](docs/VnetsApi.md#edit_vnet_routing_service_using_put) | **PUT** /api/latest/vnets/{uuid}/routing-service | Update routing service for a VNET
*VnetsApi* | [**get_firewall_profile_for_vnet_using_get**](docs/VnetsApi.md#get_firewall_profile_for_vnet_using_get) | **GET** /api/latest/vnets/{uuid}/firewall-profile | View a firewall profile for a VNET
*VnetsApi* | [**get_vnet_using_get**](docs/VnetsApi.md#get_vnet_using_get) | **GET** /api/latest/vnets/{uuid} | View the properties for a VNET
*VnetsApi* | [**get_vnets_using_get**](docs/VnetsApi.md#get_vnets_using_get) | **GET** /api/latest/vnets | View VNETs for an organization
*VnetsApi* | [**link_nfv_instance_to_vnet_using_put**](docs/VnetsApi.md#link_nfv_instance_to_vnet_using_put) | **PUT** /api/latest/vnets/{uuid}/link-nfv-instance | Link a NFV instance to a VNET
*VnetsApi* | [**remove_nfv_instance_from_vnet_using_put**](docs/VnetsApi.md#remove_nfv_instance_from_vnet_using_put) | **PUT** /api/latest/vnets/{uuid}/remove-nfv-instance | Remove a NFV instance from a VNET
*VnetsApi* | [**rename_vnet_using_put**](docs/VnetsApi.md#rename_vnet_using_put) | **PUT** /api/latest/vnets/{uuid}/name | Rename a VNET
*VnetsApi* | [**unlink_nfv_instance_from_vnet_using_put**](docs/VnetsApi.md#unlink_nfv_instance_from_vnet_using_put) | **PUT** /api/latest/vnets/{uuid}/unlink-nfv-instance | Unlink a NFV instance from a VNET

## Documentation For Models

 - [ApiActionPayload](docs/ApiActionPayload.md)
 - [ApiActionStatusPayload](docs/ApiActionStatusPayload.md)
 - [ApiAddVnicPayload](docs/ApiAddVnicPayload.md)
 - [ApiApplicationGroupPayload](docs/ApiApplicationGroupPayload.md)
 - [ApiApplicationInstancePropertiesPayload](docs/ApiApplicationInstancePropertiesPayload.md)
 - [ApiApplicationInstanceStatsPayload](docs/ApiApplicationInstanceStatsPayload.md)
 - [ApiApplicationTemplateOperatingSystemPayload](docs/ApiApplicationTemplateOperatingSystemPayload.md)
 - [ApiApplicationTemplatePropertiesPayload](docs/ApiApplicationTemplatePropertiesPayload.md)
 - [ApiApplicationsForApplicationGroupPayload](docs/ApiApplicationsForApplicationGroupPayload.md)
 - [ApiAutomatedSnapshotPolicyPayload](docs/ApiAutomatedSnapshotPolicyPayload.md)
 - [ApiBootOrderPayload](docs/ApiBootOrderPayload.md)
 - [ApiCategoryAllocationForMigrationZonePayload](docs/ApiCategoryAllocationForMigrationZonePayload.md)
 - [ApiCategoryAllocationPayload](docs/ApiCategoryAllocationPayload.md)
 - [ApiComputeHardwarePropertiesPayload](docs/ApiComputeHardwarePropertiesPayload.md)
 - [ApiComputeNodeFirmwareUpdatePayload](docs/ApiComputeNodeFirmwareUpdatePayload.md)
 - [ApiComputeNodeStatsPayload](docs/ApiComputeNodeStatsPayload.md)
 - [ApiControllerStatusPayload](docs/ApiControllerStatusPayload.md)
 - [ApiCpuTemperaturePayload](docs/ApiCpuTemperaturePayload.md)
 - [ApiCreateApplicationGroupPayload](docs/ApiCreateApplicationGroupPayload.md)
 - [ApiCreateApplicationPayload](docs/ApiCreateApplicationPayload.md)
 - [ApiCreateDatacenterCategoryAllocationPayload](docs/ApiCreateDatacenterCategoryAllocationPayload.md)
 - [ApiCreateDatacenterPayload](docs/ApiCreateDatacenterPayload.md)
 - [ApiCreateDatacenterResourcePayload](docs/ApiCreateDatacenterResourcePayload.md)
 - [ApiCreateOrEditApplicationNetworkOptionsPayload](docs/ApiCreateOrEditApplicationNetworkOptionsPayload.md)
 - [ApiCreateSnapshotPayload](docs/ApiCreateSnapshotPayload.md)
 - [ApiCreateTemplateFromApplicationPayload](docs/ApiCreateTemplateFromApplicationPayload.md)
 - [ApiCreateVnetPayload](docs/ApiCreateVnetPayload.md)
 - [ApiDatacenterAllocationForMigrationZonePayload](docs/ApiDatacenterAllocationForMigrationZonePayload.md)
 - [ApiDatacenterFlashPoolPayload](docs/ApiDatacenterFlashPoolPayload.md)
 - [ApiDatacenterMigrationZonePayload](docs/ApiDatacenterMigrationZonePayload.md)
 - [ApiDatacenterPropertiesPayload](docs/ApiDatacenterPropertiesPayload.md)
 - [ApiDisasterRecoveryPolicyPayload](docs/ApiDisasterRecoveryPolicyPayload.md)
 - [ApiDisasterRecoveryRetentionCountPayload](docs/ApiDisasterRecoveryRetentionCountPayload.md)
 - [ApiDiskBandwidthPayload](docs/ApiDiskBandwidthPayload.md)
 - [ApiDiskIopsPayload](docs/ApiDiskIopsPayload.md)
 - [ApiDiskPayload](docs/ApiDiskPayload.md)
 - [ApiDiskSizeAndLimitPayload](docs/ApiDiskSizeAndLimitPayload.md)
 - [ApiDiskSizePayload](docs/ApiDiskSizePayload.md)
 - [ApiDiskStatsPayload](docs/ApiDiskStatsPayload.md)
 - [ApiEditApplicationGroupPayload](docs/ApiEditApplicationGroupPayload.md)
 - [ApiEditApplicationPayload](docs/ApiEditApplicationPayload.md)
 - [ApiFirewallProfilePropertiesPayload](docs/ApiFirewallProfilePropertiesPayload.md)
 - [ApiFirewallProfileRulePropertiesPayload](docs/ApiFirewallProfileRulePropertiesPayload.md)
 - [ApiFlashPoolAllocationPayload](docs/ApiFlashPoolAllocationPayload.md)
 - [ApiFlashPoolPropertiesPayload](docs/ApiFlashPoolPropertiesPayload.md)
 - [ApiFlashPoolStatsPayload](docs/ApiFlashPoolStatsPayload.md)
 - [ApiImportVmToApplicationTemplatePayload](docs/ApiImportVmToApplicationTemplatePayload.md)
 - [ApiMarketplaceTemplatePayload](docs/ApiMarketplaceTemplatePayload.md)
 - [ApiMarketplaceTemplatePropertiesPayload](docs/ApiMarketplaceTemplatePropertiesPayload.md)
 - [ApiMessagePayload](docs/ApiMessagePayload.md)
 - [ApiMigrationZoneAllocationPayload](docs/ApiMigrationZoneAllocationPayload.md)
 - [ApiMigrationZonePropertiesPayload](docs/ApiMigrationZonePropertiesPayload.md)
 - [ApiMigrationZoneStatsPayload](docs/ApiMigrationZoneStatsPayload.md)
 - [ApiNamePayload](docs/ApiNamePayload.md)
 - [ApiNetworkPayload](docs/ApiNetworkPayload.md)
 - [ApiNotificationPayload](docs/ApiNotificationPayload.md)
 - [ApiOsVersionOptionsPayload](docs/ApiOsVersionOptionsPayload.md)
 - [ApiSharedStoragePayload](docs/ApiSharedStoragePayload.md)
 - [ApiSimpleIdPayload](docs/ApiSimpleIdPayload.md)
 - [ApiSimplePayload](docs/ApiSimplePayload.md)
 - [ApiSlamActionRequestPayload](docs/ApiSlamActionRequestPayload.md)
 - [ApiSlamActionRequestWithMessagePayload](docs/ApiSlamActionRequestWithMessagePayload.md)
 - [ApiSnapshotBootOrderPayload](docs/ApiSnapshotBootOrderPayload.md)
 - [ApiSnapshotDisasterRecoveryInformationPayload](docs/ApiSnapshotDisasterRecoveryInformationPayload.md)
 - [ApiSnapshotPayload](docs/ApiSnapshotPayload.md)
 - [ApiStaticBindingRulePayload](docs/ApiStaticBindingRulePayload.md)
 - [ApiStorageBlockPayload](docs/ApiStorageBlockPayload.md)
 - [ApiStorageControllerPayload](docs/ApiStorageControllerPayload.md)
 - [ApiUiTagPayload](docs/ApiUiTagPayload.md)
 - [ApiUpdateNetworksForDatacenterPayload](docs/ApiUpdateNetworksForDatacenterPayload.md)
 - [ApiUpdateTagsForComputeNodePayload](docs/ApiUpdateTagsForComputeNodePayload.md)
 - [ApiUserPayload](docs/ApiUserPayload.md)
 - [ApiUuidPayload](docs/ApiUuidPayload.md)
 - [ApiVersionPayload](docs/ApiVersionPayload.md)
 - [ApiVlanPropertiesPayload](docs/ApiVlanPropertiesPayload.md)
 - [ApiVnetDhcpServicePayload](docs/ApiVnetDhcpServicePayload.md)
 - [ApiVnetPayload](docs/ApiVnetPayload.md)
 - [ApiVnetPropertiesPayload](docs/ApiVnetPropertiesPayload.md)
 - [ApiVnetRoutingServicePayload](docs/ApiVnetRoutingServicePayload.md)
 - [ApiVnicPayload](docs/ApiVnicPayload.md)

## Documentation For Authorization


## apiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

[amadsen@lenovo.com](mailto:amadsen@lenovo.com)
